@@ -7,9 +7,9 @@ import logging
 import os
 import re
 
-__author__ = 'Greg Albrecht W2GMD <oss@undef.net>'
-__copyright__ = 'Copyright 2020 Orion Labs, Inc.'
-__license__ = 'Apache License, Version 2.0'
+__author__ = "Greg Albrecht W2GMD <oss@undef.net>"
+__copyright__ = "Copyright 2020 Orion Labs, Inc."
+__license__ = "Apache License, Version 2.0"
 
 
 if bool(os.environ.get('DEBUG')):
@@ -23,5 +23,6 @@ else:
     LOG_FORMAT = logging.Formatter(
         ('%(asctime)s aiscot %(levelname)s - %(message)s'))
 
-DEFAULT_COT_PORT: int = 8087
 DEFAULT_AIS_PORT: int = 5050
+DEFAULT_STALE: int = 600
+DEFAULT_TYPE: str = "a-n-S-X-M"
